@@ -19,6 +19,9 @@ int loadwords(char *stringi)
 	}
 	makkara = malloc(21 * sizeof(char));
 	while ((nakki = getc(wordfile)) != EOF) {
+		if (wordcount>=WORD_MAX) {
+			break;	/* don't read more than max words */
+		}
 		switch (nakki) {
 		case 0x0d:
 			break;
@@ -59,7 +62,7 @@ void freewords()
 	int i;
 
 	for (i = 0; i < wordcount; i++)
-		free(word[wordcount]);
+		free(word[i]);
 
 }
 
@@ -77,7 +80,7 @@ int choose_wordfile(int kumpi)
 	char *info;
 	//char *thingie[50];
 	char thingie[WORDFILE_MAX][62];
-	char merkk;
+	int merkk;
 
 
 	filena = malloc(4 * sizeof(char));
@@ -266,7 +269,7 @@ int resetscorefile(char *sanafile)
 	float etyporatio[10] =
 	{10, 10, 10, 10, 10, 10, 10, 10, 0, 0};
 	char efaim[10][21] =
-	{"3l33t", "Pro", "VeryGood", "Good", "Average", "NoGood", "ADP-Pro", "Looser", "None", "None"};
+	{"3l33t", "Pro", "VeryGood", "Good", "Average", "NoGood", "ADP-Pro", "Loser", "None", "None"};
 
 
 	filetys = (char *) malloc(sizeof(char) * (strlen(sanafile) + strlen(".high") + 1));
@@ -485,7 +488,7 @@ void readconfig()
 {
 
 	FILE *conffile;
-	char wordhakemisto[81];
+	char wordhakemisto[1025];
 	char tmp[10];
 	char *userhome;
 
@@ -493,14 +496,13 @@ void readconfig()
 	sprintf(userhome,getenv("HOME"));
 	strcat(userhome,"/");
 	strcat(userhome,LOCALCONF);
-	hakemisto = malloc(82 * sizeof(char));
-	getcwd(hakemisto, 80);
+	hakemisto = malloc(1026 * sizeof(char));
+	getcwd(hakemisto, 1024);
 	conffile = fopen(CONFIGFILE, "r");
 	if (conffile != NULL) {
-		// didn't work           | fgets(wordhakemisto,80,conffile);
-		// we use fscanf then :D | fgets(tmp,6,conffile);
-		fscanf(conffile, "%s", wordhakemisto);
-		fscanf(conffile, "%s", tmp);
+		fgets(wordhakemisto,1024,conffile);
+		fgets(tmp,6,conffile);
+		while (iscntrl(wordhakemisto[strlen(wordhakemisto)-1])) wordhakemisto[strlen(wordhakemisto)-1] = '\0';
 		if (!strcmp(tmp, "cheat"))
 			opt.cheat = 1;
 		fclose(conffile);
@@ -508,8 +510,9 @@ void readconfig()
 	}
 	conffile = fopen(userhome, "r");
 	if (conffile != NULL) {
-		fscanf(conffile, "%s", wordhakemisto);
-		fscanf(conffile, "%s", tmp);
+		fgets(wordhakemisto,1024,conffile);
+		fgets(tmp,6,conffile);
+		while (iscntrl(wordhakemisto[strlen(wordhakemisto)-1])) wordhakemisto[strlen(wordhakemisto)-1] = '\0';
 		if (!strcmp(tmp, "cheat"))
 			opt.cheat = 1;
 		fclose(conffile);
