@@ -231,7 +231,7 @@ int play() {
     while (misses < 10 && escend < 1) {
 	/*
 	   while ((timenow()) < (oldtimes + 30 - warp)||pause) { */
-	while ((timenow()) < (oldtimes + (1 / rate) * 100) || pause) {
+	while ((timenow()) < (oldtimes + (1.0 / rate) * 100) || pause) {
 	
 	    /* debug: */ 
 	    //mvprintw(24,1,"%d %d",inputpos,strlen(input));
@@ -622,7 +622,7 @@ int main(int argc, char *argv[]) {
     int wheretogo=0;
     int want_help = 0;
 
-    char serv[64];
+    char serv[256];
 
     opt.cheat = DEFAULT_CHEAT;
     opt.training = DEFAULT_TRAINING;
@@ -672,7 +672,7 @@ int main(int argc, char *argv[]) {
 	    opt.client = 1;
 	    if (!optarg)
 		abort();	/* getopt should handle this... */
-	    strcpy(serv, optarg);
+	    strncpy(serv, optarg, 255);
 	    break;
 	case 'p':
 	    if (optarg) opt.port = atoi(optarg);    
